@@ -49,6 +49,10 @@ _git_delete_branch(){
   __gitcomp "$(__git_heads)"
 }
 
+_git_delete_squashed_branches(){
+  __gitcomp "$(__git_heads)"
+}
+
 _git_delete_submodule(){
   __gitcomp "$(git submodule status | awk '{print $2}')"
 }
@@ -150,3 +154,7 @@ _git_info(){
 _git_browse(){
   __git_complete_remote_or_refspec
 }
+
+_git_browse_ci(){
+  __git_complete_remote_or_refspec
+}
