@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 make_install() {
     if [ -n "$PREFIX" ]
@@ -9,13 +9,14 @@ make_install() {
     fi
 }
 
-cd /tmp \
-    && rm -rf ./git-extras \
+dir=$(mktemp -t -d git-extras-install.XXXXXXXXXX) \
+    && cd "$dir" \
     && echo "Setting up 'git-extras'...." \
     && git clone https://github.com/tj/git-extras.git &> /dev/null \
     && cd git-extras \
     && git checkout \
         $(git describe --tags $(git rev-list --tags --max-count=1)) \
         &> /dev/null \
-    && make_install
+    && make_install \
+    && rm -rf "$dir"
 
